document.addEventListener('DOMContentLoaded', function() {
    const priceSlider = document.getElementById('priceSlider');
    const sliderFill = document.getElementById('sliderFill');
    const homeValueDisplay = document.getElementById('homeValueDisplay');
    const savings = document.getElementById('savings');
    const lowCommission = document.getElementById('lowCommission');
    const highCommission = document.getElementById('highCommission');
    
    // Format currency function
    function formatCurrency(amount) {
        return new Intl.NumberFormat('en-US', {
            style: 'currency',
            currency: 'USD',
            minimumFractionDigits: 0,
            maximumFractionDigits: 0
        }).format(amount);
    }
    
    // Update slider fill
    function updateSliderFill() {
        const min = parseInt(priceSlider.min);
        const max = parseInt(priceSlider.max);
        const val = parseInt(priceSlider.value);
        const percentage = ((val - min) / (max - min)) * 100;
        
        sliderFill.style.width = percentage + '%';
    }
    
    // Update calculator function
    function updateCalculator() {
        const homePrice = parseInt(priceSlider.value);
        const lowCommissionAmount = homePrice * 0.015;
        const highCommissionAmount = homePrice * 0.03;
        const savingsAmount = highCommissionAmount - lowCommissionAmount;
        
        homeValueDisplay.textContent = `${formatCurrency(homePrice)} home value`;
        savings.textContent = formatCurrency(savingsAmount);
        lowCommission.textContent = `Nectr: ${formatCurrency(lowCommissionAmount)}`;
        highCommission.textContent = `Traditional broker: ${formatCurrency(highCommissionAmount)}`;
        
        updateSliderFill();
    }
    
    // Initialize calculator
    updateCalculator();
    
    // Add event listener for slider change
    priceSlider.addEventListener('input', updateCalculator);
});